PDF Knowledgebase MCP
Description: PDF Knowledgebase MCP - Semantic search and management for PDF documents

Loading...

## Document Library

Loading documents...

### No documents found

Upload your first PDF document to get started

Showing 1-20 of 100

## Search Documents

Results:
Min Score: 0.0

Searching...

### No results found

Try different keywords or adjust your search criteria

## Upload Documents

### Drop PDF files here

or

### Add by File Path

### Upload Queue

### Confirm Action

Are you sure?